@extends('layouts.print')

@section('header')
<p class="header-text">
    @foreach (Session::get('semesters_info') as $index => $semester_info)
        {{ $semester_info }}
        @if($index+1 != count(Session::get('semesters_info')))
        <strong>&#183;</strong>
        @endif
    @endforeach
</p>
<p class="header-text">Assessment Results</p>
<h1 class="header-text">School of {{{ $school->name}}}</h1>
@stop

@section('main')

 
<h3>Programs</h3>
<table class="tabletable-condensed">
    <tr>
        <th>Name</th>
        <th>Participation</th>
    </tr>
    @foreach ($school->programs as $program)
        <tr>
            <td>{{ $program->name }}</td>
            <td class="text-center">
                @if(in_array($program->id, $participating_programs))
                    <span class="glyphicon glyphicon-ok"></span>
                @else
                    -
                @endif
            </td>
        </tr>
    @endforeach
</table>
<br>
<br>
<br>
<div class="row">
    <div class="col-md-12" id="graph-undergrad"></div>
</div>
<h3>Assessment Results by Learning Outcomes in Academic Undergraduate Programs</h3>
<table>
    <thead>
        <th>Learning Outcome</th>
        <th>Programs Achieved</th>
        <th>Programs doing Assessment</th>
        <th>Success Rate</th>
    </thead>
    <tbody>
        @foreach($outcomes_undergrad as $outcome)
        <?php $count = 0;?>
            <tr>
                <td class="col-md-6">{{ $outcome->name }}</td>
                <td class="col-md-2">{{{ count($attemptedUndergradProgramsPerOutcome[$outcome->id]) }}}</td>
                @foreach($undergrad_programs as $program)
                    <?php
                        if(isset($achievedUndergradProgramsPerOutcome[$outcome->id][$program->id])
                            && $achievedUndergradProgramsPerOutcome[$outcome->id][$program->id] / $attemptedUndergradProgramsPerOutcome[$outcome->id][$program->id] * 100 >= $expected_target_for_undergradprograms)
                        $count++;
                                                

                                                
                            ?>

                @endforeach

                <td class="col-md-2">{{{ $count }}}</td>
                <td class="col-md-2">
                @if(count($attemptedUndergradProgramsPerOutcome[$outcome->id])!=0)
                    {{{ round( $count / count($attemptedUndergradProgramsPerOutcome[$outcome->id])*100, 2) }}}%
                @else
                    N/M
                @endif
                </td>
            </tr>
        @endforeach
    </tbody>
    <tfoot></tfoot>
    <caption>N/M: Not Measured</caption>
</table>

<h3>Courses</h3>
@if($undergrad_school_sections_count>0)
    <table>
        <thead>
            <tr>
                <th>Identifier</th>
                <th>Name</th>
                <th>Program</th>
                <th>Assessed and Published</th>
            </tr>
        </thead>
        <tbody>
            @foreach($undergrad_grouped_courses as $grouped_course)
                <tr>
                    <td class="col-md-2">{{ $grouped_course->code.$grouped_course->number.' ('.$grouped_course->semester->code.')' }}</td>
                    <td class="col-md-4">{{{ $grouped_course->name}}}</td>
                    <td class="col-md-2">{{{ $grouped_course->program->name }}}</td>
                    <td class="col-md-1">
                        @if($grouped_course->outcomes_attempted!=NULL)
                            Yes
                        @else
                            No
                        @endif
                    </td>
                </tr>
            @endforeach
        </tbody>
    </table>
@else
    <p class="lead"> No courses assigned.</p>
@endif

<h3>Sections</h3>
@if($undergrad_school_sections_count>0)
<p class="lead"> {{{ $undergrad_assessed_sections_count }}} out of {{{ $undergrad_school_sections_count }}} section(s) doing Assessment ({{{ round($undergrad_assessed_sections_count/$undergrad_school_sections_count*100, 2) }}}%)</p>
<table>
        <thead>
            <tr>
                <th>Identifier</th>
                <th>Name</th>
                <th>Program</th>
                <th>Professor</th>
                <th>Assessed Activities</th>
                <th>Assessed Results</th>
            </tr>
        </thead>
        <tbody>
            @foreach($school->programs as $program)
            @if(!$program->is_graduate)
                @foreach($program->courses as $course)
               
                <tr>
                    <td class="col-md-2">{{ $course->code.$course->number.'-'.$course->section.' ('.$course->semester->code.')' }}</td>
                    <td class="col-md-4">{{{ $course->name}}}</td>
                    <td class="col-md-2">{{{ $course->program->name }}}</td>
                    <td class="col-md-3">{{{ $course->user->surnames }}}, {{{ $course->user->first_name }}}</td>
                    <td class="col-md-1">
                        @if(count($course->assessedActivities))
                            Yes
                        @else
                            No
                        @endif
                    </td>
                    <td class="col-md-1">
                        @if(count($course->publishedActivities))
                            Yes
                        @else
                            No
                        @endif
                    </td>
                </tr>
                @endforeach
            @endif
            @endforeach
        </tbody>
    </table>
@else
    <p class="lead"> No sections assigned.</p>
@endif


<br>
<br>
<br>
<div class="row">
    <div class="col-md-12" id="graph-grad"></div>
</div>


<h3>Assessment Results by Learning Outcomes in Academic Graduate Programs</h3>
<table>
    <thead>
        <th>Learning Outcome</th>
        <th>Programs Achieved</th>
        <th>Programs doing Assessment</th>
        <th>Success Rate</th>
    </thead>
    <tbody>
        @foreach($outcomes_grad as $outcome)
        <?php $count = 0;?>
            <tr>
                <td class="col-md-6">{{ link_to_action('OutcomesController@show', $outcome->name, array($outcome->id), $attributes = array()) }}</td>
                <td class="col-md-2">{{{ count($attemptedGradProgramsPerOutcome[$outcome->id]) }}}</td>
                @foreach($grad_programs as $program)
                <?php
                if(isset($achievedGradProgramsPerOutcome[$outcome->id][$program->id])
                    && $achievedGradProgramsPerOutcome[$outcome->id][$program->id] / $attemptedGradProgramsPerOutcome[$outcome->id][$program->id] * 100 >= $expected_target_for_gradprograms)
                $count++;
                

                
                    ?>

            @endforeach
                <td class="col-md-2">{{{ $count }}}</td>
                <td class="col-md-2">
                    @if(count($attemptedGradProgramsPerOutcome[$outcome->id])!=0)
                        {{{ round($count / count($attemptedGradProgramsPerOutcome[$outcome->id])*100, 2) }}}%
                    @else
                        N/M
                    @endif
                </td></tr>
                @endforeach
    </tbody>
    <tfoot></tfoot>
    <caption>N/M: Not Measured</caption>
</table>


<h3>Courses</h3>
@if($grad_school_sections_count>0)
    <table>
        <thead>
            <tr>
                <th>Identifier</th>
                <th>Name</th>
                <th>Program</th>
                <th>Assessed and Published</th>
            </tr>
        </thead>
        <tbody>
            @foreach($grad_grouped_courses as $grouped_course)
                <tr>
                    <td class="col-md-2">{{ $grouped_course->code.$grouped_course->number.' ('.$grouped_course->semester->code.')' }}</td>
                    <td class="col-md-4">{{{ $grouped_course->name}}}</td>
                    <td class="col-md-2">{{{ $grouped_course->program->name }}}</td>
                    <td class="col-md-1">
                        @if($grouped_course->outcomes_attempted!=NULL)
                            Yes
                        @else
                            No
                        @endif
                    </td>
                </tr>
            @endforeach
        </tbody>
    </table>
@else
    <p class="lead"> No courses assigned.</p>
@endif

<h3>Sections</h3>
@if($grad_school_sections_count>0)
<p class="lead"> {{{ $grad_assessed_sections_count }}} out of {{{ $grad_school_sections_count }}} section(s) doing Assessment ({{{ round($grad_assessed_sections_count/$grad_school_sections_count*100, 2) }}}%)</p>
<table>
        <thead>
            <tr>
                <th>Identifier</th>
                <th>Name</th>
                <th>Program</th>
                <th>Professor</th>
                <th>Assessed Activities</th>
                <th>Assessed Results</th>
            </tr>
        </thead>
        <tbody>
            @foreach($school->programs as $program)
            @if($program->is_graduate)
                @foreach($program->courses as $course)
               
                <tr>
                    <td class="col-md-2">{{ $course->code.$course->number.'-'.$course->section.' ('.$course->semester->code.')' }}</td>
                    <td class="col-md-4">{{{ $course->name}}}</td>
                    <td class="col-md-2">{{{ $course->program->name }}}</td>
                    <td class="col-md-3">{{{ $course->user->surnames }}}, {{{ $course->user->first_name }}}</td>
                    <td class="col-md-1">
                        @if(count($course->assessedActivities))
                            Yes
                        @else
                            No
                        @endif
                    </td>
                    <td class="col-md-1">
                        @if(count($course->publishedActivities))
                            Yes
                        @else
                            No
                        @endif
                    </td>
                </tr>
                @endforeach
            @endif
            @endforeach
        </tbody>
    </table>
@else
    <p class="lead"> No sections assigned.</p>
@endif
@stop

@section('included-js')

<!-- HighCharts -->
<script src="{{ asset('vendor/highcharts/highcharts.js') }}"></script>
<!--script src="http://code.highcharts.com/modules/exporting.js"></script -->

@stop

@section('javascript')
$(function () {

    $('#schoolTabs a').click(function (e) {
        e.preventDefault()
        $(this).tab('show');
    });
    
    $('#graph-grad').highcharts({
        chart: {
            type: 'bar'
        },
        title: {
            text: 'Graduate Performance by {{ $school->name }} Students by Learning Outcome Criteria'
        },
        legend: {
            reversed: true,
        },
        xAxis: {
            categories: [
                @foreach($outcomes_grad as $outcome)
                    "{{{ $outcome->name }}} <br> (N = {{$grad_outcomes_attempted[$outcome->id]}} , {{$grad_outcomes_achieved[$outcome->id]}})",
                @endforeach
            ],
            labels: {
                style: {
                    fontSize:'11px'
                },
                step:1,
                useHTML:true,
                formatter: function() {
                    return '<div style="width:200px; word-break:break; text-overflow:ellipsis; overflow:hidden;">'+this.value+'</div>';
                },
            }
        },
        yAxis: {
            min: 0,
            max: 100,
            title: {
                text: 'Percentage'
            },
            
        @if(isset($default_grad))
            plotLines:[{
        value:70,
        color: '#000',
        width:3,
        zIndex:4,
        label:{
            text: 'Goal (70%)',
            style: {
                color: '#000',
                fontSize: '14px',
            }

        }
    }]
    @else
    plotLines:[{
        value:{{$linea_grad->expected_target}},
        color: '#000',
        width:3,
        zIndex:4,
        label:{
            text: 'Goal ({{$linea_grad->expected_target}}%)',
            style: {
                color: '#000',
                fontSize: '14px',
            }

        }
    }]

    @endif
        },
        tooltip: {
            headerFormat: '<span style="font-size:10px">{point.key}</span><table>',
            pointFormat: '<tr><td style="color:{series.color};padding:0">{series.name}: </td>' +
                '<td style="padding:0"><b>{point.y:.2f}</b></td></tr>',
            footerFormat: '</table>',
            shared: true,
            useHTML: true
        },
        plotOptions: {
            bar: {
                //grouping: false,
                shadow: false,
                borderWidth: 0,
            },
            series: {
            pointPadding: 0,
            groupPadding: 0.075
            },
        },
        series: [/*{
            name: 'Expected Value',
            color: '#555555',
            dataLabels: {
                enabled: true,
                fontSize: 8,
                color: '#fff',
                align: 'right',
                format: '{y:.1f}%',
                style: {
                    //fontWeight: 'bold'
                },
                y:-1
            },
            data: [
                @foreach($outcomes_grad as $index => $outcome)
                    @if(
                        is_array($grad_outcomes_attempted)
                        && array_key_exists($outcome->id, $grad_outcomes_attempted)
                        && $grad_outcomes_attempted[$outcome->id]!=0)
                        {{{ $outcome->expected_outcome }}},
                    @else
                        0,
                    @endif
                @endforeach
            ],
            pointPadding: 0,
        }, */{
            name: 'Obtained Value',
            color: '#e70033',
            dataLabels: {
                enabled: true,
                fontSize: 8,
                color: '#fff',
                align: 'right',
                format: '{y:.1f}%',
                style: {
                    //fontWeight: 'bold'
                },
                y:-1
            },
            data:[
                @foreach($outcomes_grad as $index => $outcome)
                    @if(
                        is_array($grad_outcomes_attempted)
                        && array_key_exists($outcome->id, $grad_outcomes_attempted)
                        && $grad_outcomes_attempted[$outcome->id]!=0)
                        <?php
                         if (isset($grad_outcomes_achieved[$outcome->id]))
                        $achieved = $grad_outcomes_achieved[$outcome->id];
                        else {
                            $achieved =0;
                        }
                        ?>
                        {{{ ($achieved/$grad_outcomes_attempted[$outcome->id])*100 }}},
                    @else
                        0,
                    @endif
                @endforeach
            ],
            pointPadding: 0,
        }]
    });
});

    $('#graph-undergrad').highcharts({
        chart: {
            type: 'bar'
        },
        title: {
            text: 'Undergraduate Performance of {{ $school->name }} Students by Learning Outcome'
        },
        legend: {
            reversed: true,
        },
        xAxis: {
            categories: [
                @foreach($outcomes_undergrad as $outcome)
                    "{{{ $outcome->name }}},  <br> (N = {{$undergrad_outcomes_attempted[$outcome->id]}} ,{{$undergrad_outcomes_achieved[$outcome->id]}})",
                @endforeach
            ],
            labels: {
                style: {
                    fontSize:'11px'
                },
                step:1,
                useHTML:true,
                formatter: function() {
                    return '<div style="width:200px; word-break:break; text-overflow:ellipsis; overflow:hidden;">'+this.value+'</div>';
                },
            }
        },
        yAxis: {
            min: 0,
            max: 100,
            title: {
                text: 'Percentage'
            }, 
        @if(isset($default_undergrad))
            plotLines:[{
        value:70,
        color: '#000',
        width:3,
        zIndex:4,
        label:{
            text: 'Goal (70%)',
            style: {
                color: '#000',
                fontSize: '14px',
            }

        }
    }]
    @else
    plotLines:[{
        value:{{$linea_undergrad->expected_target}},
        color: '#000',
        width:3,
        zIndex:4,
        label:{
            text: 'Goal ({{$linea_undergrad->expected_target}}%)',
            style: {
                color: '#000',
                fontSize: '14px',
            }

        }
    }]

    @endif
        },
        tooltip: {
            headerFormat: '<span style="font-size:10px">{point.key}</span><table>',
            pointFormat: '<tr><td style="color:{series.color};padding:0">{series.name}: </td>' +
                '<td style="padding:0"><b>{point.y:.2f}</b></td></tr>',
            footerFormat: '</table>',
            shared: true,
            useHTML: true
        },
        plotOptions: {
            bar: {
                //grouping: false,
                shadow: false,
                borderWidth: 0,
            },
            series: {
            pointPadding: 0,
            groupPadding: 0.075
            },
        },
        series: [/*{
            name: 'Expected Value',
            color: '#555555',
            dataLabels: {
                enabled: true,
                fontSize: 8,
                color: '#fff',
                align: 'right',
                format: '{y:.1f}%',
                style: {
                    //fontWeight: 'bold'
                }, 
                y:-1
            },
            data: [
                @foreach($outcomes_undergrad as $index => $outcome)
                    @if(
                        is_array($undergrad_outcomes_attempted)
                        && array_key_exists($outcome->id, $undergrad_outcomes_attempted)
                        && $undergrad_outcomes_attempted[$outcome->id]!=0)
                        {{{ $outcome->expected_outcome }}},
                    @else
                        0,
                    @endif
                @endforeach
            ],
            pointPadding: 0,
        },*/ {
            name: 'Obtained Value',
            color: '#e70033',
            dataLabels: {
                enabled: true,
                fontSize: 8,
                color: '#fff',
                align: 'right',
                format: '{y:.1f}%',
                style: {
                    //fontWeight: 'bold'
                },
                y:-1
            },
            data:[
                @foreach($outcomes_undergrad as $index => $outcome)
                    @if(
                        is_array($undergrad_outcomes_attempted)
                        && array_key_exists($outcome->id, $undergrad_outcomes_attempted)
                        && $undergrad_outcomes_attempted[$outcome->id]!=0)
                        <?php
                        
                        if (isset($undergrad_outcomes_achieved[$outcome->id]))
                        $achieved = $undergrad_outcomes_achieved[$outcome->id];
                        else {
                            $achieved =0;
                        }
                        
                        ?>
                        {{{ ($achieved/$undergrad_outcomes_attempted[$outcome->id])*100 }}},
                    @else
                        0,
                    @endif
                @endforeach
            ],
            pointPadding: 0,
        }]
    });


   

    // Include dummy graph for outcomes
    @include('global.dummy-outcomes')


@stop
