@extends('layouts.master')

@section('navigation')
  @if($role==1)
    @include('local.managers.admins._new_navigation')
  @elseif($role==2)
    @include('local.managers.sCoords._new_navigation')
  @elseif($role==3)
    @include('local.managers.pCoords._new_navigation')
  @else
    @include('local.professors._navigation')
  @endif
@stop

@section('main')
  <div class="row">
    <div class="col-md-12">
      <div class="btn-group pull-right">
        {{ HTML::linkAction('ActivitiesController@show', 'Back to Activity', array($activity->id), array('class'=>'btn btn-default')) }}
        {{ HTML::linkAction('RubricsController@printview', 'Print', array($activity->id, $rubric->id), array('class'=>'btn btn-default')) }}
      </div>
      <p id="course">Course: {{{ $course->code }}} {{{ $course->number }}}</p>
      <p id="section">Section: {{{ $course->section }}}</p>
      <p id="activity" data-activity-id="{{{ $activity->id }}}">Activity: {{{ $activity->name}}} </p>
      <p>Passing Criteria:
        <span id="expected_percentage">{{{ $rubric->expected_percentage }}}% of students must obtain at least </span>
        <span id="expected_points">{{{$rubric->expected_points}}}</span> points
      </p>

      <table class="table table-striped table-condensed">
        <thead>
          <tr>
            <th></th>
            <th>Criterion</th>
            @for($i = 0; $i<$rubric->num_scales; $i++)
            <th> {{$rubric->titles[$i]}} ({{1+($i*($rubric->max_score/$rubric->num_scales))}} - {{(1+$i)*($rubric->max_score/$rubric->num_scales)}})</th>
            @endfor
            <th>Learning Outcome</th>
          </tr>
        </thead>
        <tbody>
        @foreach($rubric_criterion as $index => $criterion)
          <tr data-criterion-copyright="{{ $criterion->copyright }}" data-criterion-notes="{{ $criterion->notes }}">
            <td>{{ $index + 1 }}.</td>
            @if(isset($criterion->notes))
            <td>
              <span><em data-toggle="tooltip" data-placement="top" title="{{ $criterion->notes }}">{{{ $criterion->name }}}</em></span>
              <sup></sup>
              @if($criterion->subcriteria)
                <ul class="list-unstyled">
                 
                  @foreach(json_decode($criterion->subcriteria) as $subcriterion)
                      <li>{{ $subcriterion }}</li>
                  @endforeach
                </ul>
              @endif
            </td>
            @else
            <td>
              <span>{{{ $criterion->name }}}</span><sup></sup>
              @if($criterion->subcriteria)
                <ul class="list-unstyled">
                  @foreach(json_decode($criterion->subcriteria) as $subcriterion)
                      <li>{{ $subcriterion }}</li>
                  @endforeach
                </ul>
              @endif
            </td>
            @endif
            @foreach(json_decode($criterion->scales) as $scale)
            <td>{{ nl2br($scale) }}</td>

            @endforeach

            <td>
            
            @foreach (json_decode($criterion->outcomes) as $index => $outcome)
<!--             {{$index+1}}. {{$outcome}}<br>                  -->
            {{$outcome}}<br>                 
            @endforeach  
            </td>
          </tr>
        @endforeach
        </tbody>
      </table>


      <div id="copyright-info">
        <hr>
        <p class="small"><strong>Copyright Information</strong></p>
        <ul id="copyright-list" class="list-unstyled small">
        </ul>
        <hr>
      </div>
    </div>
  </div>
@stop


@section('javascript')

  // --------------------------------------------------------------------------
  // Page load
  // --------------------------------------------------------------------------

  buildCopyrightList();

  // --------------------------------------------------------------------------
  // Functions
  // --------------------------------------------------------------------------

  // Build list from copyright info in rubric
  function buildCopyrightList()
  {
    // Empty the copyright list
    $('#copyright-list').empty();

    $('tbody tr').each(function( index )
    {
      var criterion = $(this);
      // If there's copyright info (in this particular view, it checks for empty strings)
      if(criterion.data('criterion-copyright')!='')
      {
        // console.log('Copyright for index '+index+' not null.');
        var copyright = criterion.data('criterion-copyright');

        // If there is anything in the copyright list
        if($('#copyright-list li').length>0)
        {
          // console.log('In index '+index+', copyright list not empty.');

          // Check copyright list for the same copyright text
          var found = false;
          $('#copyright-list li').each(function()
          {
            // If found, give the string its number
            if(copyright==$(this).find('span').text())
            {
              // console.log('In index '+index+', matching copyright test found.');
              copyrightNumber = Number.parseInt($(this).find('sup').text());
              // console.log('In index '+index+', the matching number is '+copyrightNumber);

              // console.log('In index '+index+', text is'+ criterion.children('td:nth-child(1)').text());

              criterion.children('td:nth-child(2)').find('sup').text(copyrightNumber);
              found =true;

              //to break
              return false;
            }
          });

          // Otherwise, give it the next number and append a new item to the
          // list
          if(!found)
          {
            // console.log('In index '+index+', matching copyright test NOT found.');
            var copyrightNumber = $('#copyright-list li').length+1;
            criterion.children('td:nth-child(2)').find('sup').text(copyrightNumber);
            $('#copyright-list').append('<li><sup>'+copyrightNumber+' </sup><span>'+copyright+'<span></li>');
          }
        }
        // Otherwise, give it number 1 and append it
        else
        {
          // // console.log('In index '+index+', copyright list is empty.');

          criterion.children('td:nth-child(2)').find('sup').text('1');
          $('#copyright-list').append('<li><sup>1 </sup><span>'+copyright+'<span></li>');
        }
      }
    });

    if($('#copyright-info li').length>0)
    {
      $('#copyright-info').show();
    }
    else
    {
      $('#copyright-info').hide();
    }
  }

@stop